@@ -1,4 +1,4 @@
-from tonclient.types import ParamsOfParse, ParamsOfQueryCollection
+from tonclient.types import ParamsOfParse, ParamsOfQueryCollection, ResultOfQueryCollection
 
 from tvmbase.client import Client
 from tvmbase.models.data import AccountData
@@ -20,13 +20,22 @@ class Account(BaseTvm):
             filter={'id': {'eq': address}},
         )
 
+    @classmethod
+    async def from_query_result(cls, client: Client, idx: str, result: ResultOfQueryCollection) -> 'Account':
+        try:
+            boc = result.result[0]['boc']
+        except IndexError:
+            boc = None
+        return await cls.from_boc(client, boc, idx=idx)
+
     @classmethod
     async def from_boc(cls, client: Client, boc: str, **kwargs) -> 'Account':
+        kw_address = kwargs.pop('idx', None)
         if boc is None:  # account is not exists
-            return cls(client, kwargs['id'], data=None)
+            return cls(client, kw_address, data=None)
         parse_params = ParamsOfParse(boc=boc)
         parsed = await client.boc.parse_account(params=parse_params)
-        address = parsed.parsed.pop('id')
+        address = parsed.parsed['id']
         data = AccountData(**parsed.parsed, **kwargs)
         return cls(client, address, data)
 
