@@ -27,6 +27,6 @@ class Transaction(BaseTvm):
         parsed = await client.boc.parse_transaction(params=parse_params)
         parsed_dict = parsed.parsed
         convert_nested(parsed_dict, TransactionData)
-        idx = parsed.parsed.pop('id')
+        idx = parsed.parsed['id']
         data = TransactionData(**parsed_dict, **kwargs)
         return cls(client, idx, data)
